#[non_exhaustive]pub enum DecoderErrorKind {
DuplicateStreamId,
DecodeFailed,
FeedFailed,
InvalidHeader,
}Expand description
The kind of decoder error that occurred.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DuplicateStreamId
The stream ID already has a pending header block.
DecodeFailed
The C decoder returned an error during decoding.
FeedFailed
The C decoder returned an error when processing encoder stream data.
InvalidHeader
An error occurred while processing a decoded header (e.g., invalid UTF-8).