#[non_exhaustive]pub enum EncoderErrorKind {
InvalidHeader,
InitFailed,
EncodeFailed,
EndHeaderFailed,
FeedFailed,
}Expand description
The kind of encoder error that occurred.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidHeader
The header could not be converted (e.g., invalid UTF-8 or too long).
InitFailed
The C encoder returned an error during initialization.
EncodeFailed
The C encoder returned an error during encoding.
EndHeaderFailed
The C encoder failed to finalize the header block.
FeedFailed
The C encoder returned an error when processing decoder stream data.